agentle.mcp.models
==================

.. automodule:: agentle.mcp.models

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   annotations
   blob_resource_contents
   call_tool_result
   embedded_resource
   image_content
   resource_contents
   role
   text_content
   text_resource_contents
